package com.cool.bang.modules.mysql.service;

import com.cool.bang.common.util.DateUtil;
import com.cool.bang.modules.mysql.domain.*;
import com.cool.bang.modules.mysql.domain.flowPo.ApprovalFlow;
import com.cool.bang.modules.mysql.domain.flowPo.ApprovalNode;
import com.cool.bang.modules.mysql.domain.flowPo.ApprovalRecord;
import com.cool.bang.modules.mysql.mapper.*;
import com.cool.bang.modules.oracle.domain.Areg;
import com.cool.bang.modules.oracle.domain.AregItem;
import com.cool.bang.modules.oracle.domain.Bxmxy;
import com.cool.bang.modules.oracle.domain.Trade;
import com.cool.bang.modules.oracle.domain.po.*;
import com.cool.bang.modules.oracle.mapper.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.StringUtils;

import javax.swing.event.ListDataEvent;
import java.math.BigDecimal;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.util.stream.Stream;

@Service
public class MySQLService {

    @Autowired
    private MySqlMapper mySqlMapper;
    @Autowired
    private OracleMapper oracleMapper;
    @Autowired
    private OrgMapper qyxxMapper;
    @Autowired
    private BankMapper bankMapper;
    @Autowired
    private ProjectMapper projectMapper;
    @Autowired
    private AccountMapper accountMapper;
    @Autowired
    private AregMapper aregMapper;
    @Autowired
    private BuildingMapper buildingMapper;
    @Autowired
    private ProjectAccountMapper projectAccountMapper;
    @Autowired
    private BuildingAccountMapper buildingAccountMapper;
    @Autowired
    private BxmxyMapper bxmxyMapper;
    @Autowired
    private FlowMapper flowMapper;
    @Autowired
    private SysUserMapper userMapper;
    @Autowired
    private TrusteeshipMapper trusteeshipMapper;
    @Autowired
    private ApplyMapper applyMapper;
    @Autowired
    private TradeMapper tradeMapper;
    @Autowired
    private ProgressConfigMapper progressConfigMapper;
    @Autowired
    private FWMapper fwMapper;

    /**
     * 项目表 数据匹配
     */
    public void project() {
        //对应YSZJJG--BXM表

        System.out.println("===============fc_project 数据匹配开始=================");
        List<Map<String, Object>> list = oracleMapper.selectFromBxm();

        List<Project> projectList = new ArrayList<>();
        for (Map<String, Object> map : list) {
            Integer JGZT = Integer.parseInt(map.get("JGZT").toString());
            if (JGZT == 0) {
                continue;
            }
            Project project = new Project(map);
            List<Map<String, Object>> aregs = oracleMapper.selectAregByXmbh((String) map.get("XMBH"));
            boolean jg = false;
            if (aregs.size() == 1) {
                String jsstate = (String) aregs.get(0).get("JGSTATE");
                if (jsstate.equals("-1")) {
                    project.setState(0);
                }
                if (jsstate.equals("1")) {
                    project.setState(1);
                }
            } else {
                for (Map<String, Object> areg : aregs) {
                    String jsstate = (String) areg.get("JGSTATE");
                    if (jsstate.equals("1")) {
                        jg = true;
                    }
                }
                project.setState(jg ? 1 : 0);
            }

            Org org = qyxxMapper.selectOrgByMisid(Integer.parseInt(map.get("QYBH").toString().trim()));
//            if (org == null){
//                project.setOrgId(0);
//            }else {
            project.setOrgId(org.getId());
//            }
            //查询该项目下房屋总套数
            Integer houseTotal = projectMapper.selectProjectHouseTotal(project.getProjectNumber());
            project.setHouseTotal(houseTotal == null ? 0 : houseTotal);
            projectList.add(project);
        }
        int i = projectMapper.insertProject(projectList);
        System.out.println("===============fc_project 数据匹配结束==插入" + i + "条数据==============");
    }


    /**
     * 账户表 数据匹配
     */
    public void account() {
        //对应ACCOUNT表
        System.out.println("===============fc_account 数据匹配开始=================");
        List<Map<String, Object>> list = oracleMapper.selectFromAccount();

        List<Account> accountList = new ArrayList<>();
        for (Map<String, Object> map : list) {
            Account account = new Account(map);
            if (map.get("QYBH") != null) {
                Org org = qyxxMapper.selectOrgByMisid(Integer.parseInt(map.get("QYBH").toString().trim()));
                account.setOrgId(org.getId());
                account.setOrgName(org.getOrgName());
                account.setName(org.getOrgName());
            }
            if (map.get("XMBH") != null) {
                Project project = projectMapper.selectByProjectNumber((String) map.get("XMBH"));
                if (project != null) {
                    account.setProjectId(project.getId());
                    account.setProjectName(project.getProjectName());
                    account.setProjectNumber(project.getProjectNumber());
                }
            }
            //查询账户在途资金
            BigDecimal inTransitFund = oracleMapper.selectAccountInTransitFund(Integer.parseInt(map.get("ACCOUNTID").toString()));
            if (inTransitFund != null) {
                account.setInTransitFund(inTransitFund);
            }
            accountList.add(account);
        }
        int i = accountMapper.insertAccount(accountList);

        //查询账号的数据
        List<Long> ids = accountMapper.selectReuseAcoount();
        for (Long id : ids) {
            accountMapper.deleteById(id);
        }

        System.out.println("===============fc_account 数据匹配结束==插入" + i + "条数据==============");
    }


    /**
     * 项目账户表 楼幢账户表 数据匹配
     */
    @Transactional
    public void projectAccount() {
        //对应YSZJJG--AREG、AREGITEM表
        System.out.println("===============fc_project_account fc_building_account数据匹配开始=================");

        //从yszjjg库查询项目虚拟户以及楼幢虚拟户
        List<Areg> aregList = aregMapper.selectFromAreg();

        for (Areg areg : aregList) {
            List<AregItem> aregItemList = areg.getAregItemList();
            for (AregItem aregItem : aregItemList) {
                if (aregItem.getAregitemid() != null) {
                    //查询楼幢信息
                    Building building = buildingMapper.selectByBuildingNumber(aregItem.getLzbh());
                    aregItem.setBuilding(building);
                    //查询楼幢虚拟户托管、监管在途资金
                    aregItem.setTgzt(aregMapper.selectLzTgzt(aregItem.getAregitemid()));
                    aregItem.setJgzt(aregMapper.selectLzJgzt(aregItem.getAregitemid()));
                }
            }

            //查询项目信息
            Project project = projectMapper.selectByProjectNumber(areg.getXmbh());
            ProjectAccount projectAccount = new ProjectAccount(project, areg);
            if (areg.getTgzh() != null) {
                Account account = accountMapper.selectByAccountNO(areg.getTgzh());
                projectAccount.setBankCode(account.getBankCode());
                projectAccount.setBankName(account.getBankName());
                projectAccount.setAccountId(account.getId());
            }

            //插入
            int i = projectAccountMapper.insertProjectAccount(projectAccount);
            System.out.println("*******************");
            System.out.println(projectAccount.getProjectName() + "插入完成");
            if (projectAccount.getBuildingAccountList().size() > 0) {
                int n = buildingAccountMapper.insertBuildingAccount(projectAccount.getId(), projectAccount.getBuildingAccountList());
                System.out.println("插入楼幢虚拟户数据" + n + "条");
            }
            // 更新每个项目虚拟户留存金额
            projectAccountMapper.updateKeepAmount(projectAccount.getId());
            if (projectAccount.getAccountType() == 1) {
                projectAccountMapper.updateTrusteeshipInTransit(projectAccount.getId());
            }
            if (projectAccount.getAccountType() == 2) {
                projectAccountMapper.updateSuperviseInTransit(projectAccount.getId());
            }
            System.out.println("*******************");
        }
        // 更新楼幢相关数据
        projectMapper.updateBuildArea();
        projectMapper.updateBuildTotal();
        System.out.println("===============fc_project_account fc_building_account数据匹配结束==============");
    }

    /**
     * 托管申请表 托管协议表 导入 托管申请的APPTYPE = 0
     */
    @Transactional
    public void trusteeshipBusiness() {
        System.out.println("===============fc_trusteeship_agreement fc_trusteeship_business 数据匹配开始=================");

        List<Bxmxy> xmxyList = bxmxyMapper.selectFromBxmxy();

        System.out.println("查询出项目协议信息共"+ xmxyList.size() + "条");

        //查询流程信息
        ApprovalFlow approvalFlow = flowMapper.selectFlowByType(1); //托管申请flowType = 1
        //查询节点信息
        List<ApprovalNode> nodeList = flowMapper.selectNodeByFlowNumber(approvalFlow.getFlowNumber());

        for (Bxmxy bxmxy : xmxyList) {
            Project project = projectMapper.selectByProjectNumber(bxmxy.getXmbh());
            Org org = qyxxMapper.selectOrgByMisid(Integer.valueOf(bxmxy.getQybh()));
            if (org == null) { //测试用
                org = new Org();
                org.setId(3);
                org.setOrgName("山东酷邦软件有限公司");
            }

            TrusteeshipBusiness trusteeshipBusiness = new TrusteeshipBusiness(project, org, bxmxy);

            trusteeshipBusiness.setFlowNumber(approvalFlow.getFlowNumber());

            if (bxmxy.getBljd() == 1) { //申请
                // 添加开始节点
                ApprovalNode approvalNode = nodeList.get(0);
                trusteeshipBusiness.setFlowNodeId(approvalNode.getNextNodeId());
                trusteeshipBusiness.setFlowNodeName(approvalNode.getNodeName());
                trusteeshipMapper.insertTrusteeshipBusiness(trusteeshipBusiness);

                // 添加审批记录
                ApprovalRecord approvalRecord = new ApprovalRecord();
                approvalRecord.setBusinessNumber(trusteeshipBusiness.getBusinessNumber());
                approvalRecord.setFlowNumber(trusteeshipBusiness.getFlowNumber());
                approvalRecord.setTableId(trusteeshipBusiness.getId());
                approvalRecord.setNodeId(trusteeshipBusiness.getFlowNodeId());
                approvalRecord.setNodeName(trusteeshipBusiness.getFlowNodeName());
                approvalRecord.setApprover(org.getOrgName());
                approvalRecord.setApprovalTime(DateUtil.strToDate(bxmxy.getSqsj(), "yyyy-MM-dd HH:mm:ss"));
                approvalRecord.setDelFlag(1);
                flowMapper.insertRecord(approvalRecord);
            } else { //已经审核
                // 开始节点
                ApprovalNode startNode = nodeList.get(0);
                // 结束节点
                ApprovalNode endNode = nodeList.get(1);

                trusteeshipBusiness.setFlowNodeId(nodeList.get(2).getId());
                trusteeshipBusiness.setFlowNodeName(nodeList.get(2).getNodeName());
                trusteeshipMapper.insertTrusteeshipBusiness(trusteeshipBusiness);

                // 添加审批记录
                ApprovalRecord startNodeRecord = new ApprovalRecord();
                startNodeRecord.setBusinessNumber(trusteeshipBusiness.getBusinessNumber());
                startNodeRecord.setFlowNumber(trusteeshipBusiness.getFlowNumber());
                startNodeRecord.setTableId(trusteeshipBusiness.getId());
                startNodeRecord.setNodeId(startNode.getId());
                startNodeRecord.setNodeName(startNode.getNodeName());
                startNodeRecord.setApprover(org.getOrgName());
                startNodeRecord.setApprovalTime(DateUtil.strToDate(bxmxy.getSqsj(), "yyyy-MM-dd HH:mm:ss"));
                startNodeRecord.setDelFlag(1);
                flowMapper.insertRecord(startNodeRecord);

                ApprovalRecord endNodeRecord = new ApprovalRecord();
                endNodeRecord.setBusinessNumber(trusteeshipBusiness.getBusinessNumber());
                endNodeRecord.setFlowNumber(trusteeshipBusiness.getFlowNumber());
                endNodeRecord.setTableId(trusteeshipBusiness.getId());
                endNodeRecord.setNodeId(endNode.getId());
                endNodeRecord.setNodeName(endNode.getNodeName());
                endNodeRecord.setApproverId(null);
                endNodeRecord.setApprover("监管部门");
                endNodeRecord.setApprovalTime(DateUtil.strToDate(bxmxy.getShsj(), "yyyy-MM-dd HH:mm:ss"));
                endNodeRecord.setApprovalStatus(1);
                endNodeRecord.setApprovalRemark("无");
                endNodeRecord.setDelFlag(1);
                flowMapper.insertRecord(endNodeRecord);

                //已经审核通过的添加托管协议信息、签章信息
                TrusteeshipAgreement trusteeshipAgreement = new TrusteeshipAgreement(trusteeshipBusiness, bxmxy);

                String tgzh = bxmxy.getTgzh();
                if (tgzh != null) {
                    if (tgzh.contains(",")) {//是否包含逗号，包含的说明两家托管银行
                        String[] arr = tgzh.split(",");
                        Account account1 = accountMapper.selectByAccountNO(arr[0]);
                        trusteeshipAgreement.setTrusteeship0AccountId(account1.getId());
                        trusteeshipAgreement.setTrusteeship0Account(account1.getAccount());
                        trusteeshipAgreement.setTrusteeship0Bank(account1.getBankName());
                        trusteeshipAgreement.setTrusteeship0BankCode(account1.getBankCode());
                        trusteeshipAgreement.setTrusteeship0Range(bxmxy.getJgld());

                        Account account2 = accountMapper.selectByAccountNO(arr[1]);
                        trusteeshipAgreement.setTrusteeship1AccountId(account2.getId());
                        trusteeshipAgreement.setTrusteeship1Account(account2.getAccount());
                        trusteeshipAgreement.setTrusteeship1Bank(account2.getBankName());
                        trusteeshipAgreement.setTrusteeship1BankCode(account2.getBankCode());
                        trusteeshipAgreement.setTrusteeship1Range(bxmxy.getJgld());
                    } else {
                        Account account = accountMapper.selectByAccountNO(tgzh);
                        trusteeshipAgreement.setTrusteeship0AccountId(account.getId());
                    }
                }
                trusteeshipMapper.insertTrusteeshipAgreement(trusteeshipAgreement);

                //需要判断 什么时候插入的签章信息
                if (bxmxy.getCadocid() != null && bxmxy.getCaxyid() != null) {
                    Signatory signatory = new Signatory(bxmxy,trusteeshipAgreement);
                    List<Signatory> signatoryList = new ArrayList<>();
                    signatoryList.add(signatory.getSignatory());
                    signatoryList.add(signatory.getSignatory2());
                    trusteeshipMapper.insertSignatory(signatoryList);
                }
            }
        }
        System.out.println("===============fc_trusteeship_agreement fc_trusteeship_business 数据匹配结束=================");
    }

    /**
     * 监管开户申请业务表导入
     */
    @Transactional
    public void superviseBusiness() {
        System.out.println("===============fc_supervise_business数据匹配开始=================");

        List<Jgyw> jgywList = applyMapper.selectJgkh();

        List<SuperviseBusiness> superviseBusinessList = new ArrayList<>();
        for (Jgyw jgyw : jgywList) {
            Project project = projectMapper.selectByProjectNumber(jgyw.getXmbh());

            Account account = accountMapper.selectByAccountNO(jgyw.getAccountno());
            Org org = qyxxMapper.selectOrgByMisid(jgyw.getQybh());
            if (org == null) { //测试用
                org = new Org();
                org.setId(3);
                org.setOrgName("山东酷邦软件有限公司");
            }


            SuperviseBusiness superviseBusiness = new SuperviseBusiness(account, org, project, jgyw);

            superviseBusinessList.add(superviseBusiness);
        }
        int i = mySqlMapper.insertSuperviseBusiness(superviseBusinessList);

        System.out.println("===============fc_supervise_business数据匹配结束 插入数据" + i + "条==============");
    }

    /**
     * 监管项目解除
     */
    @Transactional
    public void relieve() {
        List<Jgxmjc> jgxmjcList = applyMapper.selectJgxmjc();
        List<SuperviseRelieve> superviseRelieveList = new ArrayList<>();
        ApprovalFlow approvalFlow = flowMapper.selectFlowByType(7);//解除申请flowid = 7
        List<ApprovalNode> nodes = flowMapper.selectNodeByFlowNumber(approvalFlow.getFlowNumber());
        ApprovalNode endNode = new ApprovalNode();
        for (ApprovalNode node : nodes) {
            if (node.getNumber() == 3) {
                endNode = node;
            }
        }
        List<ApprovalRecord> recordList = new ArrayList<>();

        for (Jgxmjc jgxmjc : jgxmjcList) {
            Org org = qyxxMapper.selectOrgByMisid(jgxmjc.getQybh());
            Project project = projectMapper.selectByProjectNumber(jgxmjc.getXmbh());
            ProjectAccount projectAccount = projectAccountMapper.selectByAregid(jgxmjc.getAregid());
            List<Areg> aregList = applyMapper.selectByXmbhFromAreg(jgxmjc.getXmbh());
            //项目解除业务信息
            Relieve relieve = new Relieve(jgxmjc, org, project);
            relieve.setFlowNumber(approvalFlow.getFlowNumber());
            relieve.setFlowNodeId(endNode.getId());
            relieve.setFlowNodeName(endNode.getNodeName());
            if (aregList.size() == 1) {//说明该项目下所有的项目虚拟户都已经解除，可以解除项目、项目虚拟户、账户、楼幢
                relieve.setRelieveType(1);
                mySqlMapper.insertRelieve(relieve);
                projectMapper.updateRelieve(relieve.getProjectId());
            } else { //说明该项目下存在还没有解除的项目虚拟户，所以只解除该项目虚拟户、以及该项目虚拟户绑定的账户、楼幢
                relieve.setRelieveType(2);
                mySqlMapper.insertRelieve(relieve);
            }
            //项目虚拟户变更解除状态
            projectAccountMapper.updateRelieveByAregid(jgxmjc.getAregid(), jgxmjc.getSqrq());
            //监管账户解除业务信息
            if (jgxmjc.getAccountList() != null && jgxmjc.getAccountList().size() > 0) {
                for (Account account : jgxmjc.getAccountList()) {
                    account = accountMapper.selectByAccountNO(account.getAccount());
                    SuperviseRelieve superviseRelieve = new SuperviseRelieve(account, org, projectAccount, jgxmjc);
                    superviseRelieveList.add(superviseRelieve);
                    //更新账户解除日期
                    accountMapper.updateCancelDate(account.getId(), superviseRelieve.getUpdateTime());
                }
            }
            //解除明细
            List<RelieveDetail> relieveDetailList = new ArrayList<>();
            if (jgxmjc.getAregItemList() != null && jgxmjc.getAregItemList().size() > 0) {
                for (AregItem aregItem : jgxmjc.getAregItemList()) {
                    BuildingAccount buildingAccount = buildingAccountMapper.selectByBuildingNumber(aregItem.getLzbh());
                    RelieveDetail relieveDetail = new RelieveDetail(buildingAccount);
                    relieveDetail.setRelieveId(relieve.getId());
                    relieveDetailList.add(relieveDetail);
                }
                mySqlMapper.insertRelieveDetail(relieveDetailList);
                buildingAccountMapper.updateRelieve(relieveDetailList, jgxmjc.getShrq());
            }
            //审批流程
            if (jgxmjc.getsFlowList() != null && jgxmjc.getsFlowList().size() > 0) {
                for (SFlow sFlow : jgxmjc.getsFlowList()) {
                    ApprovalRecord record = new ApprovalRecord();
                    record.setBusinessNumber(relieve.getBusinessNumber());
                    record.setFlowNumber(relieve.getFlowNumber());
                    record.setTableId(relieve.getId());
                    record.setApprovalTime(sFlow.getShsj());
                    record.setApprovalRemark(sFlow.getBz());
                    record.setCreateTime(record.getApprovalTime());
                    record.setUpdateTime(record.getApprovalTime());
                    record.setDelFlag(1);
                    if (sFlow.getShzt() == null) {
                        record.setNodeName("申请节点");
                        record.setApprover(relieve.getOrgName() + "(" + sFlow.getShr() + ")");
                    } else {
                        record.setNodeName(sFlow.getLcmc());
                        record.setApprover("监管部门(" + sFlow.getShr() + ")");
                        if (sFlow.getShzt() == 1) {
                            record.setApprovalStatus(1);
                        } else {
                            record.setApprovalStatus(2);
                        }
                    }
                    recordList.add(record);
                }
            }
        }
        mySqlMapper.insertSuperviseRelieve(superviseRelieveList);
        flowMapper.insertRecordBatch(recordList);
    }

    /**
     * 监管账户解除业务表导入
     */
    /*@Transactional
    public void superviseRelieve(){
        System.out.println("===============fc_supervise_relieve数据匹配开始=================");

        List<Jgyw> jgywList = applyMapper.selectJgjc();

        List<SuperviseRelieve> superviseRelieveList = new ArrayList<>();
        for (Jgyw jgyw : jgywList) {
            Account account = accountMapper.selectByAccountNO(jgyw.getAccountno());
            Org org = qyxxMapper.selectOrgByMisid(jgyw.getQybh());
            if (org == null){ //测试用
                org = new Org();
                org.setId(3);
                org.setOrgName("山东酷邦软件有限公司");
            }
            Project project = projectMapper.selectByProjectNumber(jgyw.getXmbh());

            SuperviseRelieve superviseRelieve = new SuperviseRelieve(account,org,project,jgyw);

            superviseRelieveList.add(superviseRelieve);

            //更新账户解除日期
            accountMapper.updateCancelDate(account.getId(),superviseRelieve.getUpdateTime());
        }
        int i = mySqlMapper.insertSuperviseRelieve(superviseRelieveList);

        System.out.println("===============fc_supervise_relieve数据匹配结束 插入数据"+i+"条==============");
    }*/

    /**
     * 监管资金转托管业务表、明细表导入
     */
    @Transactional
    public void superviseTo() {
        System.out.println("===============fc_supervise_to、fc_supervise_to_detail数据匹配开始=================");
        List<Jgztg> jgztgList = applyMapper.selectJgztg();

        //查询流程信息
        ApprovalFlow approvalFlow = flowMapper.selectFlowByType(5); //监管资金转托管flowType = 5
        //查询结束节点 节点信息
        List<ApprovalNode> approvalNodeList = flowMapper.selectNodeByFlowNumber(approvalFlow.getFlowNumber());
        ApprovalNode currentNode = new ApprovalNode();
        for (ApprovalNode approvalNode : approvalNodeList) {
            if (approvalNode.getNodeName().equals("流程结束")) {
                currentNode = approvalNode;
            }
        }

        List<SuperviseToDetail> superviseToDetailList = new ArrayList<>();
        List<ApprovalRecord> recordList = new ArrayList<>();
        List<SuperviseToOutgoing> superviseToOutgoingList = new ArrayList<>();
        List<SuperviseToPosting> superviseToPostingList = new ArrayList<>();
        for (Jgztg jgztg : jgztgList) {
            Account superviseAccount = accountMapper.selectByAccountNO(jgztg.getJgzh());
            Account trusteeshipAccount = accountMapper.selectByAccountNO(jgztg.getTgzh());
            Org org = qyxxMapper.selectOrgByMisid(jgztg.getQybh());
            if (org == null) { //测试用
                org = new Org();
                org.setId(3);
                org.setOrgName("山东酷邦软件有限公司");
            }
            Project project = projectMapper.selectByProjectNumber(jgztg.getXmbh());

            //业务表
            SuperviseTo superviseTo = new SuperviseTo(superviseAccount, trusteeshipAccount, org, project, jgztg);
            superviseTo.setFlowNumber(approvalFlow.getFlowNumber());
            superviseTo.setFlowNodeId(currentNode.getId());
            superviseTo.setFlowNodeName(currentNode.getNodeName());
            mySqlMapper.insertSuperviseTo(superviseTo);

            //明细表
            List<Jgztgmx> jgztgmxList = jgztg.getJgztgmxList();
            for (Jgztgmx jgztgmx : jgztgmxList) {
                BuildingAccount buildingAccount = buildingAccountMapper.selectByBuildingNumber(jgztgmx.getLzbh());
                SuperviseToDetail superviseToDetail = new SuperviseToDetail(buildingAccount, jgztgmx);
                superviseToDetail.setSuperviseToId(superviseTo.getId());
                superviseToDetail.setCreateTime(superviseTo.getCreateTime());
                superviseToDetail.setUpdateTime(superviseTo.getUpdateTime());
                superviseToDetailList.add(superviseToDetail);
            }

            //查询交易信息
            Trade trade = new Trade();
            trade.setTradenum(jgztg.getPaycode());
            trade.setTradestate("1");
            List<Trade> trades = tradeMapper.selectFromTrade(trade);
            //出账记录
            Trade tradeCz = new Trade();
            //入账记录
            Trade tradeRz = new Trade();
            for (Trade t : trades) {
                if (t.getTradecode().equals("1002")) {
                    tradeRz = t;
                } else if (t.getTradecode().equals("3002")) {
                    tradeCz = t;
                }
            }

            //出账通知书
            SuperviseToNotice superviseToNotice = new SuperviseToNotice();
            superviseToNotice.initNotice(superviseTo);

            SuperviseToOutgoing superviseToOutgoing = new SuperviseToOutgoing();
            superviseToOutgoing.initNotice(superviseTo);
            superviseToOutgoing.setBusinessNumber(jgztg.getPaycode());
            if (tradeCz.getId() != null) {
                superviseToOutgoing.setAppropriationStatus(1);
                superviseToOutgoing.setUpdateTime(DateUtil.dateToStr(tradeCz.getTradedate(), "yyyy-MM-dd HH:mm:ss"));
            } else {
                superviseToOutgoing.setAppropriationStatus(0);
            }
            superviseToOutgoingList.add(superviseToOutgoing);

            //入账通知书
            SuperviseToPosting superviseToPosting = new SuperviseToPosting();
            superviseToPosting.initNotice(superviseTo);
            superviseToPosting.setBusinessNumber(jgztg.getPaycode());
            if (tradeRz.getId() != null) {
                superviseToPosting.setPostingStatus(1);
                superviseToPosting.setUpdateTime(DateUtil.dateToStr(tradeCz.getTradedate(), "yyyy-MM-dd HH:mm:ss"));
            } else {
                superviseToPosting.setPostingStatus(0);
            }
            superviseToPostingList.add(superviseToPosting);

            for (SFlow sFlow : jgztg.getsFlowList()) {
                ApprovalRecord record = new ApprovalRecord();
                record.setBusinessNumber(jgztg.getYwbh());
                record.setFlowNumber(approvalFlow.getFlowNumber());
                record.setTableId(superviseTo.getId());
                record.setApprovalTime(sFlow.getShsj());
                record.setApprovalRemark(sFlow.getBz());
                record.setCreateTime(record.getApprovalTime());
                record.setUpdateTime(record.getApprovalTime());
                record.setDelFlag(1);
                if (sFlow.getLcmc().equals("监管资金转托管申请上报")) {
                    record.setNodeName("申请节点");
                    record.setApprover(org.getOrgName() + "(" + sFlow.getShr() + ")");
                } else {
                    record.setNodeName(sFlow.getLcmc());
                    record.setApprover("监管部门(" + sFlow.getShr() + ")");
                    record.setApprovalStatus(1);
                }
                recordList.add(record);
            }
        }
        mySqlMapper.insertSuperviseToDetail(superviseToDetailList);
        flowMapper.insertRecordBatch(recordList);
        mySqlMapper.insertSuperviseToPosting(superviseToPostingList);
        mySqlMapper.insertSuperviseToOutgoing(superviseToOutgoingList);
    }

    /**
     * 工程形象进度业务表、明细表导入
     */
    @Transactional
    public void progressBusiness() {
        System.out.println("===============fc_progress_business、fc_progress_detail数据匹配开始=================");
        Long a = new Date().getTime();
        List<Gcjdsq> gcjdsqList = oracleMapper.selectPromProgress();
        Long b = new Date().getTime();
        System.out.println("************************");
        System.out.println("耗时");
        System.out.println((b - a) / 1000);

        Gcjdsq lastGcjdsq = gcjdsqList.get(gcjdsqList.size() - 1);

        //查询版本号为1的工程进度标准
        List<ProgressConfig> progressConfigList = progressConfigMapper.selectByVersion(1);
        //当前申请节点
        ProgressConfig currProgressConfig = new ProgressConfig();
        //查询流程信息
        ApprovalFlow approvalFlow = flowMapper.selectFlowByType(2); //工程形象进度申请flowType = 2
        //查询结束节点 节点信息
        List<ApprovalNode> approvalNodeList = flowMapper.selectNodeByFlowNumber(approvalFlow.getFlowNumber());

        ApprovalNode node1 = approvalNodeList.get(0);
        ApprovalNode node2 = approvalNodeList.get(1);
        ApprovalNode node3 = approvalNodeList.get(2);

        List<ApprovalRecord> recordList = new ArrayList<>();

        List<ProgressDetail> progressDetailList = new ArrayList<>();

        int index = 0;
        for (Gcjdsq gcjdsq : gcjdsqList) {

            Org org = qyxxMapper.selectOrgByMisid(gcjdsq.getQybh());
            BuildingAccount buildingAccount = buildingAccountMapper.selectByBuildingNumber(gcjdsq.getLzbh());
            ProjectAccount projectAccount = projectAccountMapper.selectByAregid(gcjdsq.getAregid());

            for (ProgressConfig progressConfig : progressConfigList) {
                if (progressConfig.getLimitPercentage().compareTo(gcjdsq.getSqjd()) == 0) {
                    currProgressConfig = progressConfig;
                }
            }

            Progress progress = new Progress(org, projectAccount, gcjdsq);
            progress.setFlowNumber(approvalFlow.getFlowNumber());

            if (progress.getBusinessState() == 1) { //待审核
                progress.setFlowNodeId(node1.getId());
                progress.setFlowNodeName(node1.getNodeName());
                mySqlMapper.insertProgress(progress);

                ApprovalRecord record = new ApprovalRecord();
                record.setBusinessNumber(progress.getBusinessNumber());
                record.setFlowNumber(approvalFlow.getFlowNumber());
                record.setTableId(progress.getId());
                record.setNodeId(node1.getId());
                record.setNodeName(node1.getNodeName());
                record.setApprover(progress.getOrgName() + "(" + gcjdsq.getSqr() + ")");
                record.setApprovalTime(gcjdsq.getSqsj());
                record.setCreateTime(gcjdsq.getSqsj());
                record.setUpdateTime(gcjdsq.getSqsj());
                recordList.add(record);
            } else {
                progress.setFlowNodeId(node3.getId());
                progress.setFlowNodeName(node3.getNodeName());
                mySqlMapper.insertProgress(progress);

                ApprovalRecord record1 = new ApprovalRecord();
                record1.setBusinessNumber(progress.getBusinessNumber());
                record1.setFlowNumber(approvalFlow.getFlowNumber());
                record1.setTableId(progress.getId());
                record1.setNodeId(node1.getId());
                record1.setNodeName(node1.getNodeName());
                record1.setApprover(progress.getOrgName() + "(" + gcjdsq.getSqr() + ")");
                record1.setApprovalTime(gcjdsq.getSqsj());
                record1.setCreateTime(gcjdsq.getSqsj());
                record1.setUpdateTime(gcjdsq.getSqsj());

                ApprovalRecord record2 = new ApprovalRecord();
                record2.setBusinessNumber(progress.getBusinessNumber());
                record2.setFlowNumber(approvalFlow.getFlowNumber());
                record2.setTableId(progress.getId());
                record2.setNodeId(node2.getId());
                record2.setNodeName(node2.getNodeName());
                record2.setApprover("监管部门");
                record2.setApprovalTime(gcjdsq.getShsj());
                record2.setCreateTime(gcjdsq.getShsj());
                record2.setUpdateTime(gcjdsq.getShsj());
                if (progress.getBusinessState() == 3) { //审核通过
                    record2.setApprovalStatus(1);
                } else { //审核驳回
                    record2.setApprovalStatus(2);
                }

                recordList.add(record1);
                recordList.add(record2);
            }

            ProgressDetail detail = new ProgressDetail(buildingAccount, currProgressConfig, gcjdsq);
            detail.setProgressBusinessId(progress.getId());
            progressDetailList.add(detail);

            index++;
            //数据量达到200条时存一次 或 已到最后一条数据直接存
            if (index == 200 || gcjdsq.getId().equals(lastGcjdsq.getId())) { //200条数据为1组
                mySqlMapper.insertProgressDetail(progressDetailList);
                progressDetailList.clear();
                flowMapper.insertRecordBatch(recordList);
                recordList.clear();
                index = 0;
            }
        }
        System.out.println("===============fc_progress_business、fc_progress_detail数据匹配结束=================");
    }

    /**
     * 拨付业务信息导入
     */
    @Transactional
    public void appropriation() {
        System.out.println("===============fc_appropriation、fc_appropriation_detail数据匹配开始=================");

        /**
         * 监管拨付
         * 额度内拨付（apptype=6 flowid=4）
         * 业务表只存一条数据 监管出账通知书插入一条数据
         * -----------------------------------------------------------------------------
         * 额度外拨付（apptype=7 flowid=5）
         * 业务表只存一条数据 监管出账通知书插入一条数据
         * =============================================================================
         * 托管拨付 （托管拨付中需要监管户过渡的时候，payitem表中gdaccountid不为空）
         * 额度内拨付（apptype=18 flowid=18） 其中特批通道拨付【政府拨付】（apply表中zgflag=1）
         * 政府拨付：托管户 -> 一般户 政府发起拨付业务时只可以从托管额度内资金申请
         * 业务表只存一条数据 托管出账通知书插入一条数据
         * -----------------------------------------------------------------------------
         * 正常拨付：
         *  gdaccountid不为空时，即 托管户 -> 监管户 -> 一般户
         *  业务表插入两条数据 1.托管户->监管户 2.监管户->一般户
         *  托管出账通知书 监管入账通知书 监管出账通知书
         *
         *  gdaccountid为空时, 即 托管户 -> 账户（这里填入的可能为监管户也可能为一般户，但是统一视为一般户处理）
         *  业务表插入一条数据
         *  托管出账通知书插入一条数据
         * -----------------------------------------------------------------------------
         * 额度外拨付（apptype=19 flowid=19）
         *  gdaccountid不为空时，即 托管户 -> 监管户 -> 一般户
         *  业务表插入两条数据 1托管户->监管户 2监管户->一般户
         *  托管出账通知书 监管入账通知书 监管出账通知书
         *
         *  gdaccountid为空时, 即 托管户 -> 账户（这里填入的可能为监管户也可能为一般户，但是统一视为一般户处理）
         *  业务表插入一条数据
         *  托管出账通知书插入一条数据
         */

        //查询流程信息
        ApprovalFlow approvalFlow = flowMapper.selectFlowByType(4); //工程形象进度申请flowType = 4
        //查询结束节点 节点信息
        List<ApprovalNode> approvalNodeList = flowMapper.selectNodeByFlowNumber(approvalFlow.getFlowNumber());

        ApprovalNode endNode = new ApprovalNode();

        for (ApprovalNode node : approvalNodeList) {
            if (node.getNumber() == 4) {
                endNode = node;
            }
        }

        List<ApprovalRecord> recordList = new ArrayList<>();
        List<AppropriationOutgoing> outgoingList = new ArrayList<>();
        List<AppropriationPosting> postingList = new ArrayList<>();
        List<AppropriationDetail> detailList = new ArrayList<>();

        int index = 0;

        //监管额度内拨付
        /*List<Bfxx> jgednList = applyMapper.selectBfxx(6,4);
        Bfxx lastJgedn = jgednList.get(jgednList.size() - 1);
        for (Bfxx bfxx : jgednList) {
            Account bfzh = accountMapper.selectByAccountNO(bfxx.getBfzh());
//            Account skzh = accountMapper.selectByAccountNO(bfxx.getSkzh());

            Org org = qyxxMapper.selectOrgByMisid(bfxx.getQybh());
            ProjectAccount projectAccount = projectAccountMapper.selectByAregid(bfxx.getAregid());

            Appropriation appropriation = new Appropriation(bfxx,bfzh,null,org,projectAccount);
            appropriation.setCollectionType(2);
            appropriation.setAppropriationType(2);
            appropriation.setApplicationType(1);
            appropriation.setFlowNumber(approvalFlow.getFlowNumber());
            appropriation.setFlowNodeId(endNode.getId());
            appropriation.setFlowNodeName(endNode.getNodeName());
            mySqlMapper.insertAppropriation(appropriation);

            recordList.addAll(getBfFlow(bfxx.getsFlowList(),appropriation));
            outgoingList.add(getAppropriationOutgoing(appropriation,4));

            index ++;
            //数据量达到200条时存一次 或 已到最后一条数据直接存
            if (index == 200 || lastJgedn.getYwbh().equals(bfxx.getYwbh())){ //200条数据为1组
                flowMapper.insertRecordBatch(recordList);
                recordList.clear();
                if (outgoingList.size()>0){
                    mySqlMapper.insertAppropriationOutgoing(outgoingList);
                    outgoingList.clear();
                }
                index = 0;
            }
        }*/

        //监管额度外拨付
        /*List<Bfxx> jgedwList = applyMapper.selectBfxx(7,5);
        Bfxx lastJgedw = jgedwList.get(jgedwList.size() - 1);
        for (Bfxx bfxx : jgedwList) {
            Account bfzh = accountMapper.selectByAccountNO(bfxx.getBfzh());
            Org org = qyxxMapper.selectOrgByMisid(bfxx.getQybh());
            ProjectAccount projectAccount = projectAccountMapper.selectByAregid(bfxx.getAregid());

            Appropriation appropriation = new Appropriation(bfxx,bfzh,null,org,projectAccount);
            appropriation.setCollectionType(2);
            appropriation.setAppropriationType(2);
            appropriation.setApplicationType(2);
            appropriation.setFlowNumber(approvalFlow.getFlowNumber());
            appropriation.setFlowNodeId(endNode.getId());
            appropriation.setFlowNodeName(endNode.getNodeName());
            mySqlMapper.insertAppropriation(appropriation);

            recordList.addAll(getBfFlow(bfxx.getsFlowList(),appropriation));
            outgoingList.add(getAppropriationOutgoing(appropriation,4));

            index ++;
            //数据量达到200条时存一次 或 已到最后一条数据直接存
            if (index == 200 || lastJgedw.getYwbh().equals(bfxx.getYwbh())){ //200条数据为1组
                flowMapper.insertRecordBatch(recordList);
                recordList.clear();
                if (outgoingList.size()>0){
                    mySqlMapper.insertAppropriationOutgoing(outgoingList);
                    outgoingList.clear();
                }
                index = 0;
            }
        }*/

        //通知书类型(type) 1托管转监管户 2托管转一般户 3托管转其他户 4监管转一般户 5监管转其他户

        //托管额度内拨付
        /*List<Bfxx> tgednList = applyMapper.selectBfxx(18, 18);
        Bfxx lastTgedn = tgednList.get(tgednList.size() - 1);
        for (Bfxx bfxx : tgednList) {
            Account bfzh = accountMapper.selectByAccountNO(bfxx.getBfzh());
            Org org = qyxxMapper.selectOrgByMisid(bfxx.getQybh());
            ProjectAccount projectAccount = projectAccountMapper.selectByAregid(bfxx.getAregid());

            if (bfxx.getZgflag() != null && bfxx.getZgflag() == 1) { //政府拨付 托管户 -> 一般户
                Appropriation appropriation = new Appropriation(bfxx, bfzh, null, org, projectAccount);
                appropriation.setCollectionType(2);
                appropriation.setAppropriationType(3);
                appropriation.setApplicationType(1);
                appropriation.setFlowNumber(approvalFlow.getFlowNumber());
                appropriation.setFlowNodeId(endNode.getId());
                appropriation.setFlowNodeName(endNode.getNodeName());
                mySqlMapper.insertAppropriation(appropriation);

                if (bfxx.getBfmxList() != null && bfxx.getBfmxList().size() > 0) {
                    List<AppropriationDetail> details = getAppropriationDetail(bfxx.getBfmxList(), appropriation);
                    detailList.addAll(details);
                    //如果有楼幢拨付 变更楼幢虚拟户额度内拨付金额
                    if (appropriation.getApplicationState() == 1) {
                        buildingAccountMapper.updateInLimitFundById(details);
                    }
                }
                recordList.addAll(getBfFlow(bfxx.getsFlowList(), appropriation));
                outgoingList.add(getAppropriationOutgoing(appropriation, 2));
            } else {
                if (bfxx.getGdzh() != null) { //过渡账号不为空说明 托管户 -> 监管户 -> 一般户
                    //托管户 -> 监管户(过渡户)
                    Account gdzh = accountMapper.selectByAccountNO(bfxx.getGdzh());
                    Appropriation appropriation1 = new Appropriation(bfxx, bfzh, gdzh, org, projectAccount);
                    appropriation1.setBusinessNumber(appropriation1.getBusinessNumber() + "CZ");
                    appropriation1.setCollectionType(1);
                    appropriation1.setAppropriationType(1);
                    appropriation1.setApplicationType(1);
                    appropriation1.setFlowNumber(approvalFlow.getFlowNumber());
                    appropriation1.setFlowNodeId(endNode.getId());
                    appropriation1.setFlowNodeName(endNode.getNodeName());
                    if (bfxx.getBfzt2() == 0) {
                        appropriation1.setApplicationState(0);
                    } else {
                        appropriation1.setApplicationState(1);
                    }
                    mySqlMapper.insertAppropriation(appropriation1);

                    if (bfxx.getBfmxList() != null && bfxx.getBfmxList().size() > 0) {
                        List<AppropriationDetail> details = getAppropriationDetail(bfxx.getBfmxList(), appropriation1);
                        detailList.addAll(details);
                        //如果有楼幢拨付 变更楼幢虚拟户额度内拨付金额
                        if (appropriation1.getApplicationState() == 1) {
                            buildingAccountMapper.updateInLimitFundById(details);
                        }
                    }
                    recordList.addAll(getBfFlow(bfxx.getsFlowList(), appropriation1));
                    outgoingList.add(getAppropriationOutgoing(appropriation1, 1));
                    postingList.add(getAppropriationPosting(appropriation1));

                    //监管户(过渡户) -> 一般户
                    Appropriation appropriation2 = new Appropriation(bfxx, gdzh, null, org, projectAccount);
                    appropriation2.setBusinessNumber(appropriation2.getBusinessNumber() + "RZ");
                    appropriation2.setCollectionType(2);
                    appropriation2.setAppropriationType(2);
                    appropriation2.setApplicationType(1);
                    appropriation2.setFlowNumber(approvalFlow.getFlowNumber());
                    appropriation2.setFlowNodeId(endNode.getId());
                    appropriation2.setFlowNodeName(endNode.getNodeName());
                    if (bfxx.getBfzt2() == 2) {
                        appropriation2.setApplicationState(1);
                    } else {
                        appropriation2.setApplicationState(0);
                    }
                    mySqlMapper.insertAppropriation(appropriation2);
                    recordList.addAll(getBfFlow(bfxx.getsFlowList(), appropriation2));
                    outgoingList.add(getAppropriationOutgoing(appropriation2, 4));
                } else { //过渡账号为空说明 托管户 -> 一般户
                    Appropriation appropriation = new Appropriation(bfxx, bfzh, null, org, projectAccount);
                    appropriation.setCollectionType(2);
                    appropriation.setAppropriationType(1);
                    appropriation.setApplicationType(1);
                    appropriation.setFlowNumber(approvalFlow.getFlowNumber());
                    appropriation.setFlowNodeId(endNode.getId());
                    appropriation.setFlowNodeName(endNode.getNodeName());
                    mySqlMapper.insertAppropriation(appropriation);

                    if (bfxx.getBfmxList() != null && bfxx.getBfmxList().size() > 0) {
                        List<AppropriationDetail> details = getAppropriationDetail(bfxx.getBfmxList(), appropriation);
                        detailList.addAll(details);
                        //如果有楼幢拨付 变更楼幢虚拟户额度内拨付金额
                        if (appropriation.getApplicationState() == 1) {
                            buildingAccountMapper.updateInLimitFundById(details);
                        }
                    }
                    recordList.addAll(getBfFlow(bfxx.getsFlowList(), appropriation));
                    outgoingList.add(getAppropriationOutgoing(appropriation, 2));
                }
            }
            index++;
            //数据量达到200条时存一次 或 已到最后一条数据直接存
            if (index == 200 || lastTgedn.getYwbh().equals(bfxx.getYwbh())) { //200条数据为1组
                flowMapper.insertRecordBatch(recordList);
                recordList.clear();
                if (detailList.size() > 0) {
                    mySqlMapper.insertAppropriationDetail(detailList);
                    detailList.clear();
                }
                if (outgoingList.size() > 0) {
                    mySqlMapper.insertAppropriationOutgoing(outgoingList);
                    outgoingList.clear();
                }
                if (postingList.size() > 0) {
                    mySqlMapper.insertAppropriationPosting(postingList);
                    postingList.clear();
                }
                index = 0;
            }
        }*/

        //托管额度外拨付
        List<Bfxx> tgedwList = applyMapper.selectBfxx(19,18);
        Bfxx lastTgedw = tgedwList.get(tgedwList.size() - 1);
        for (Bfxx bfxx : tgedwList) {
            Account bfzh = accountMapper.selectByAccountNO(bfxx.getBfzh());
            Account skzh = accountMapper.selectByAccountNO(bfxx.getSkzh());
            Org org = qyxxMapper.selectOrgByMisid(bfxx.getQybh());
            ProjectAccount projectAccount = projectAccountMapper.selectByAregid(bfxx.getAregid());

            if (bfxx.getGdzh() != null){ //过渡账号不为空说明 托管户 -> 监管户 -> 一般户
                //托管户 -> 监管户(过渡户)
                Account gdzh = accountMapper.selectByAccountNO(bfxx.getGdzh());
                Appropriation appropriation1 = new Appropriation(bfxx,bfzh,gdzh,org,projectAccount);
                appropriation1.setBusinessNumber(appropriation1.getBusinessNumber()+"CZ");
                appropriation1.setCollectionType(1);
                appropriation1.setAppropriationType(1);
                appropriation1.setApplicationType(2);
                appropriation1.setFlowNumber(approvalFlow.getFlowNumber());
                appropriation1.setFlowNodeId(endNode.getId());
                appropriation1.setFlowNodeName(endNode.getNodeName());
                if (bfxx.getBfzt2() == 0){
                    appropriation1.setApplicationState(0);
                }else {
                    appropriation1.setApplicationState(1);
                }
                mySqlMapper.insertAppropriation(appropriation1);

                if (bfxx.getBfmxList() != null && bfxx.getBfmxList().size() > 0){
                    detailList.addAll(getAppropriationDetail(bfxx.getBfmxList(),appropriation1));
                }
                recordList.addAll(getBfFlow(bfxx.getsFlowList(),appropriation1));
                outgoingList.add(getAppropriationOutgoing(appropriation1,1));
                postingList.add(getAppropriationPosting(appropriation1));

                //监管户(过渡户) -> 一般户
                Appropriation appropriation2 = new Appropriation(bfxx,gdzh,null,org,projectAccount);
                appropriation2.setBusinessNumber(appropriation2.getBusinessNumber()+"RZ");
                appropriation2.setCollectionType(2);
                appropriation2.setAppropriationType(2);
                appropriation2.setApplicationType(2);
                appropriation2.setFlowNumber(approvalFlow.getFlowNumber());
                appropriation2.setFlowNodeId(endNode.getId());
                appropriation2.setFlowNodeName(endNode.getNodeName());
                if (bfxx.getBfzt2() == 2){
                    appropriation2.setApplicationState(1);
                }else {
                    appropriation2.setApplicationState(0);
                }
                mySqlMapper.insertAppropriation(appropriation2);
                recordList.addAll(getBfFlow(bfxx.getsFlowList(),appropriation2));
                outgoingList.add(getAppropriationOutgoing(appropriation2,4));
            }else { //过渡账号为空说明 托管户 -> 一般户
                Appropriation appropriation = new Appropriation(bfxx,bfzh,null,org,projectAccount);
                appropriation.setCollectionType(2);
                appropriation.setAppropriationType(1);
                appropriation.setApplicationType(2);
                appropriation.setFlowNumber(approvalFlow.getFlowNumber());
                appropriation.setFlowNodeId(endNode.getId());
                appropriation.setFlowNodeName(endNode.getNodeName());
                mySqlMapper.insertAppropriation(appropriation);

                if (bfxx.getBfmxList() != null && bfxx.getBfmxList().size() > 0){
                    detailList.addAll(getAppropriationDetail(bfxx.getBfmxList(),appropriation));
                }
                recordList.addAll(getBfFlow(bfxx.getsFlowList(),appropriation));
                outgoingList.add(getAppropriationOutgoing(appropriation,2));
            }

            index ++;
            //数据量达到200条时存一次 或 已到最后一条数据直接存
            if (index == 200 || lastTgedw.getYwbh().equals(bfxx.getYwbh())){ //200条数据为1组
                flowMapper.insertRecordBatch(recordList);
                recordList.clear();
                if (detailList.size()>0){
                    mySqlMapper.insertAppropriationDetail(detailList);
                    detailList.clear();
                }
                if (outgoingList.size()>0){
                    mySqlMapper.insertAppropriationOutgoing(outgoingList);
                    outgoingList.clear();
                }
                if (postingList.size()>0){
                    mySqlMapper.insertAppropriationPosting(postingList);
                    postingList.clear();
                }
                index = 0;
            }
        }
        System.out.println("===============fc_appropriation、fc_appropriation_detail数据匹配结束=================");
    }

    //拨付明细
    public List<AppropriationDetail> getAppropriationDetail(List<Bfmx> bfmxList, Appropriation appropriation) {
        List<AppropriationDetail> detailList = new ArrayList<>();
        for (Bfmx bfmx : bfmxList) {
            BuildingAccount buildingAccount = buildingAccountMapper.selectByBuildingNumber(bfmx.getLzbh());
            AppropriationDetail appropriationDetail = new AppropriationDetail(bfmx, appropriation, buildingAccount);
            detailList.add(appropriationDetail);
        }
        return detailList;
    }

    //拨付出账通知书
    public AppropriationOutgoing getAppropriationOutgoing(Appropriation appropriation, Integer type) {
        AppropriationNotice notice = new AppropriationNotice();
        notice.initNotice(appropriation);

        AppropriationOutgoing outgoing = new AppropriationOutgoing();
        outgoing.initNotice(appropriation, type);
        return outgoing;
    }

    //拨付入账通知书
    public AppropriationPosting getAppropriationPosting(Appropriation appropriation) {
        AppropriationNotice notice = new AppropriationNotice();
        notice.initNotice(appropriation);

        AppropriationPosting posting = new AppropriationPosting();
        posting.initNotice(appropriation);
        return posting;
    }

    //拨付审批流程
    public List<ApprovalRecord> getBfFlow(List<SFlow> sFlowList, Appropriation appropriation) {
        List<ApprovalRecord> recordList = new ArrayList<>();
        for (SFlow sFlow : sFlowList) {
            ApprovalRecord record = new ApprovalRecord();
            record.setBusinessNumber(appropriation.getBusinessNumber());
            record.setFlowNumber(appropriation.getFlowNumber());
            record.setTableId(appropriation.getId());
            record.setApprovalTime(sFlow.getShsj());
            record.setApprovalRemark(sFlow.getBz());
            record.setCreateTime(record.getApprovalTime());
            record.setUpdateTime(record.getApprovalTime());
            record.setDelFlag(1);
            if (sFlow.getShzt() == null) {
                record.setNodeName("申请节点");
                record.setApprover(appropriation.getOrgName() + "(" + sFlow.getShr() + ")");
            } else {
                //这种情况是范哥的托管额度外拨付流程与托管额度内拨付流程用的是同一个flowid，所以流程节点名称都是”额度内...“,需要此处判断替换一下
                if (appropriation.getAppropriationType() == 1 && appropriation.getApplicationType() == 2) {
                    record.setNodeName(sFlow.getLcmc().replace("内", "外"));
                } else {
                    record.setNodeName(sFlow.getLcmc());
                }
                record.setApprover("监管部门(" + sFlow.getShr() + ")");
                if (sFlow.getShzt() == 1) {
                    record.setApprovalStatus(1);
                } else {
                    record.setApprovalStatus(2);
                }
            }
            recordList.add(record);
        }
        return recordList;
    }


    /**
     * 合同导入
     */
    @Transactional
    public void htTo() {
        System.out.println("===============fc_contract 导入数据开始=================");
        Long a = new Date().getTime();
        List<HtInfo> htInfoList = oracleMapper.selectHtInfo();
        Long b = new Date().getTime();
        System.out.println("************************");
        System.out.println("查询到：" + htInfoList.size() + "条");
        System.out.println("查询耗时：" + (b - a) / 1000);


        HtInfo lastHtInfo = htInfoList.get(htInfoList.size() - 1);

        List<Contract> contracts = new ArrayList<>();

        int index = 0;
        for (HtInfo item : htInfoList) {
            Integer qybh = StringUtils.isEmpty(item.getQYBH()) ? null : Integer.valueOf(item.getQYBH());
            Org org = qyxxMapper.selectOrgByMisid(qybh);
            if (org == null) { //测试用
                org = new Org();
                org.setId(3);
                org.setOrgName("山东酷邦软件有限公司");
            }
            BuildingAccount buildingAccount = buildingAccountMapper.getInfoByLZBH(item.getLZBH());
            Long projectAccountId = (null != buildingAccount && null != buildingAccount.getProjectAccountId()) ? buildingAccount.getProjectAccountId() : null;
            ProjectAccount projectAccount = projectAccountMapper.getInfoById(projectAccountId);
            P_lpb_fw fw = fwMapper.getFwByMissid(item.getFWBH());
            List<BhtTrade> bhtTrades = oracleMapper.getBhtPayTradeByBHTID(item.getHTID());

            Contract contract = new Contract(item, buildingAccount, org, fw, projectAccount, bhtTrades);
            contracts.add(contract);
            index++;
            //数据量达到200条时存一次 或 已到最后一条数据直接存
            if (index == 200 || item.getHTID().equals(lastHtInfo.getHTID())) { //200条数据为1组
                mySqlMapper.insertContract(contracts);
                contracts.clear();
                index = 0;
            }
        }
        System.out.println("===============fc_Contract数据匹配结束=================");
    }


    /**
     * 交存导入
     */
    @Transactional
    public void htPayTo() {
        System.out.println("===============fc_fund 导入数据开始=================");
        Long a = new Date().getTime();
        List<HtPay> htPayList = oracleMapper.selectHtPayInfo();
        Long b = new Date().getTime();
        System.out.println("************************");
        System.out.println("查询到：" + htPayList.size() + "条");
        System.out.println("查询耗时：" + (b - a) / 1000);


        HtPay lastHtPay = htPayList.get(htPayList.size() - 1);

        List<Fund> funds = new ArrayList<>();

        int index = 0;
        for (HtPay item : htPayList) {
            Account account = accountMapper.selectByAccountNO(item.getACCOUNTNO());
            Long newContractId = mySqlMapper.getContractIdByNumber(item.getHTBH());
            List<BhtTrade> bhtTrades = oracleMapper.getTradeByBHTPayJKBH(item.getJKBH());
            Fund fund = new Fund(account, item, newContractId, bhtTrades);
            funds.add(fund);
            index++;
            //数据量达到200条时存一次 或 已到最后一条数据直接存
            if (index == 200 || item.getHTPAYID().equals(lastHtPay.getHTPAYID())) { //200条数据为1组
                mySqlMapper.insertFund(funds);
                funds.clear();
                index = 0;
            }
        }
        System.out.println("===============fc_Fund数据匹配结束=================");
    }


    /**
     * 定金导入
     */
    @Transactional
    public void djTo() {
        System.out.println("===============fc_earnest 导入数据开始=================");
        Long a = new Date().getTime();
        List<BDj> djList = oracleMapper.selectBDJInfo();
        Long b = new Date().getTime();
        System.out.println("************************");
        System.out.println("查询到：" + djList.size() + "条");
        System.out.println("查询耗时：" + (b - a) / 1000);


        BDj lastDj = djList.get(djList.size() - 1);

        List<Earnest> earnests = new ArrayList<>();

        int index = 0;
        for (BDj item : djList) {
            Integer qybh = StringUtils.isEmpty(item.getQYBH()) ? null : Integer.valueOf(item.getQYBH());
            Org org = qyxxMapper.selectOrgByMisid(qybh);
            if (org == null) { //测试用
                org = new Org();
                org.setId(3);
                org.setOrgName("山东酷邦软件有限公司");
            }
            BuildingAccount buildingAccount = null;
            if (!StringUtils.isEmpty(item.getLZBH())) {
                buildingAccount = buildingAccountMapper.getInfoByLZBH(item.getLZBH());
            }
            Long projectAccountId = (null != buildingAccount && null != buildingAccount.getProjectAccountId()) ? buildingAccount.getProjectAccountId() : null;
            ProjectAccount projectAccount = null;
            if (null != projectAccountId) {
                projectAccount = projectAccountMapper.getInfoById(projectAccountId);
            }
            Account account = null;
            if (!StringUtils.isEmpty(item.getACCOUNTNO())) {
                account = accountMapper.selectByAccountNO(item.getACCOUNTNO());
            }
            //BDJ TRADESTATE  是2但是TRADENUM 没有的  是退款的    BDJ 的TRADESTATE  应该是-2  退款
            if (!StringUtils.isEmpty(item.getTRADESTATE()) && "2".equals(item.getTRADESTATE()) && StringUtils.isEmpty(item.getTRADENUM())) {
                item.setTRADESTATE("-2");
            }
            Earnest earnest = new Earnest(item, buildingAccount, projectAccount, account, org);
            earnests.add(earnest);
            index++;
            //数据量达到200条时存一次 或 已到最后一条数据直接存
            if (index == 200 || item.getDJID().equals(lastDj.getDJID())) { //200条数据为1组
                mySqlMapper.insertEarnest(earnests);
                earnests.clear();
                index = 0;
            }
        }
        System.out.println("===============fc_earnest数据匹配结束=================");
    }
}
